@@ -48,7 +48,7 @@
 
 // extern list<scraprecord> SCRAPLIST;
 
-#define IOerr(F) ((std::string)"Can't open file "+F+"!\n").c_str()
+#define IOerr(F) fmt::format("Can't open file {}!\n", (F)).c_str()
 
 std::map<std::string,std::string> ALL_FONTS, ALL_PATTERNS;
 typedef std::set<unsigned char> FONTCHARS;
@@ -95,10 +95,8 @@ std::string process_pdf_string(std::string s, std::string font) {
   unsigned char c;
   char *err;
   unsigned j;
-  std::map<std::string,FONTCHARS>::iterator I; 
 
-  I = USED_CHARS.find(font);
-  if (I == USED_CHARS.end()) std::cerr << "This can't happen!";
+  auto& I = USED_CHARS.at(font); // must be there
   s = s.substr(1,s.length()-3);  // delete surrounding parentheses and final space
   for (unsigned i=0; i<s.size(); i++) {
     c = s[i];
@@ -128,9 +126,7 @@ std::string process_pdf_string(std::string s, std::string font) {
   t = "";
   for (unsigned i=0; i<r.size(); i++) {
     c = r[i];
-    if (((*I).second).find(c) == ((*I).second).end()) {
-      ((*I).second).insert(c);
-    }
+    I.insert(c);
     t += fmt::format("{:02x}",c);
   }
   return "<" + t + ">";
