@@ -26,13 +26,9 @@
  */
  
 #include "thdate.h"
-#include "thparse.h"
 #include "thexception.h"
-#include "therion.h"
-#include <sys/types.h>
 #include <time.h>
 #include <locale.h>
-#include <errno.h>
 
 void thdate::reset()
 {
