@@ -26,22 +26,15 @@
  */
  
 #include "thdb2d.h"
-#include "thexception.h"
 #include "thdatabase.h"
 #include "thparse.h"
-#include "thtfangle.h"
-#include "tharea.h"
 #include "thmap.h"
-#include "thjoin.h"
-#include "thpoint.h"
-#include "thline.h"
 #include "thscrap.h"
 #include "thsurvey.h"
-#include "thlogfile.h"
-#include <math.h>
 #include "thlayout.h"
 #include "thconfig.h"
 #include <list>
+#include <algorithm>
 #include "thmapstat.h"
 
 void thdb2d::insert_basic_maps(thdb2dxm * fmap, thmap * map, int mode, int level, thdb2dmi_shift shift) {
