@@ -35,7 +35,6 @@
 #include <vector>
 #include <string>
 #include <sstream>
-#include <iomanip>
 
 #include <cstring>
 #include <cstdio>
@@ -49,8 +48,9 @@
 #include "thtexfonts.h"
 #include "therion.h"
 #include "thdouble.h"
+#include "thexception.h"
 
-#define IOerr(F) ((std::string)"Can't open file "+F+"!\n").c_str()
+#define IOerr(F) fmt::format("Can't open file {}!\n", (F)).c_str()
 
 extern std::map<std::string,std::string> ALL_FONTS, ALL_PATTERNS;
 typedef std::set<unsigned char> FONTCHARS;
