@@ -26,8 +26,6 @@
  */
  
 #include "thgrade.h"
-#include "thexception.h"
-#include "thchenc.h"
 #include "thdata.h"
 #include "thparse.h"
 #include "thdatabase.h"
