@@ -224,10 +224,10 @@ void thinit::copy_fonts() {
 
 #ifdef THWIN32
   FILE * f = fopen(thtmp.get_file_name("pltotf.bat"),"w");
-  fprintf(f,"@\"%s\\bin\\win32\\pltotf.exe\" %%1 %%2\n",thcfg.install_path.get_buffer());
+  fprintf(f,"@\"%s\\bin\\windows\\pltotf.exe\" %%1 %%2\n",thcfg.install_path.get_buffer());
   fclose(f);
   f = fopen(thtmp.get_file_name("cfftot1.bat"),"w");
-  fprintf(f,"@\"%s\\bin\\win32\\cfftot1.exe\" %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9\n",thcfg.install_path.get_buffer());
+  fprintf(f,"@\"%s\\bin\\windows\\cfftot1.exe\" %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9\n",thcfg.install_path.get_buffer());
   fclose(f);
 #endif
   thprintf("done.\n");
@@ -367,9 +367,9 @@ void thinit::load()
     this->path_mpost = thcfg.install_path.get_buffer();
     this->path_pdftex = thcfg.install_path.get_buffer();
     this->path_otftotfm = thcfg.install_path.get_buffer();
-    this->path_mpost += "\\bin\\win32\\mpost.exe";
-    this->path_pdftex += "\\bin\\win32\\pdftex.exe";
-    this->path_otftotfm += "\\bin\\win32\\otftotfm.exe";
+    this->path_mpost += "\\bin\\windows\\mpost.exe";
+    this->path_pdftex += "\\bin\\windows\\pdftex.exe";
+    this->path_otftotfm += "\\bin\\windows\\otftotfm.exe";
   } else {
 #endif  
     this->path_mpost = "mpost";
