@@ -27,7 +27,7 @@
  
 #include "thinput.h"
 #include "thparse.h"
-#include "thchenc.h"
+#include "thchencdata.h"
 #include "therion.h"
 #include "thexception.h"
 
@@ -251,7 +251,7 @@ void thinput::open_file(char * fname)
   // if file was open, now let's try if not recursive inclusion
   ifile * tmptr;
   bool is_rec = false;
-  unsigned int n_rec = 0;
+  [[maybe_unused]] unsigned int n_rec = 0;
   
   if (!ifptr->sh.is_open()) {
     if ((srcfile != NULL) || (this->report_missing)) {
@@ -420,13 +420,13 @@ char * thinput::read_line()
           
         case TT_ENCODING:
           if (this->tmpmb.get_size() != 1)
-            therror(("%s [%d] -- encoding name expected -- %s", \
+            therror(("%s [%lu] -- encoding name expected -- %s", \
               this->get_cif_name(), this->get_cif_line_number(), \
               this->valuebf.get_buffer()));
           this->last_ptr->encoding = \
             thmatch_token(*(this->tmpmb.get_buffer()), thtt_encoding);
           if (this->last_ptr->encoding == TT_UNKNOWN_ENCODING) {
-            therror(("%s [%d] -- unknown encoding -- %s", \
+            therror(("%s [%lu] -- unknown encoding -- %s", \
               this->get_cif_name(), this->get_cif_line_number(), \
               this->valuebf.get_buffer()));
             this->last_ptr->encoding = TT_UTF_8;
