@@ -30,17 +30,22 @@
 #define thlang_h
 
 #include "thlangdata.h"
+#include "thparse.h"
 
-char * thT(char * txt, int lng = THLANG_UNKNOWN);
+const char * thT(const char * txt, int lng = THLANG_UNKNOWN);
 
-int thlang_parse(char * str);
+int thlang_parse(const char * str);
 
-char * thlang_getid(int id);
+const char * thlang_getid(int id);
 
-char * thlang_getcxxid(int id);
+const char * thlang_getcxxid(int id);
 
 int thlang_getlang(int lng);
 
+const thstok * thlang_get_text_table();
+
+void thlang_set_translation(char * lang, char * text, char * translation);
+
 #endif
 
 
