@@ -29,7 +29,7 @@
 #include "thlookup.h"
 #include "thexception.h"
 #include "thchenc.h"
-#include "thdata.h"
+#include "thtfangle.h"
 #include "thparse.h"
 #include "thinfnan.h"
 #include "thpdfdata.h"
@@ -42,6 +42,7 @@
 #include "thdatabase.h"
 #include <string.h>
 #include <filesystem>
+#include <algorithm>
 
 namespace fs = std::filesystem;
 
