@@ -28,18 +28,13 @@
 #include "thlookup.h"
 #include "thexception.h"
 #include "thchenc.h"
-#include "thdata.h"
 #include "thparse.h"
 #include "thinfnan.h"
 #include "thpdfdata.h"
-#include "thsymbolset.h"
-#include "thtflength.h"
 #include "thlang.h"
-#include "thcsdata.h"
-#include "thconfig.h"
 #include "thscrap.h"
 #include "thmap.h"
-#include "thpdf.h"
+#include "thlayout.h"
 #include "thtexfonts.h"
 #include "thdatabase.h"
 #include <string.h>
