@@ -35,7 +35,9 @@
 #include "thtexfonts.h"
 #include "thdate.h"
 #include "thscrap.h"
+#include "thobjectname.h"
 #include <string>
+#include <cstdio>
 
 
 thpoint::thpoint()
@@ -447,7 +449,7 @@ bool thpoint::export_mp(class thexpmapmpxs * out)
         out->layout->export_mptex_font_size(out->file, this, true);
         fprintf(out->file,"%s etex,",
           ((this->type == TT_POINT_TYPE_STATION_NAME) && (!this->station_name.is_empty()))
-          ? (const char *) utf2tex(thobjectname_print_full_name(this->station_name.name, this->station_name.psurvey, out->layout->survey_level))
+          ? utf2tex(thobjectname_print_full_name(this->station_name.name, this->station_name.psurvey, out->layout->survey_level)).c_str()
           : ths2tex(this->text, out->layout->lang).c_str());
         if (this->type == TT_POINT_TYPE_STATION_NAME)
           postprocess_label = "p_label_mode_station";
@@ -562,7 +564,7 @@ bool thpoint::export_mp(class thexpmapmpxs * out)
 					thpoint_export_mp_align2mp(thdb2d_rotate_align(this->align, xrr)));
         out->layout->export_mptex_font_size(out->file, this, false);
         fprintf(out->file,"%s etex,",
-					utf2tex(out->layout->units.format_length(this->xsize - out->layout->goz)));
+					utf2tex(out->layout->units.format_length(this->xsize - out->layout->goz)).c_str());
         postprocess_label = "p_label_mode_altitude";
       }
       postprocess = false;
@@ -611,11 +613,11 @@ bool thpoint::export_mp(class thexpmapmpxs * out)
           //  sprintf(buff,"%.1f",this->xsize);
           //else
           //  sprintf(buff,"%.0f",this->xsize);
-          fprintf(out->file,"%s",utf2tex(out->layout->units.format_human_length(this->xsize)));
+          fprintf(out->file,"%s",utf2tex(out->layout->units.format_human_length(this->xsize)).c_str());
         }
         this->db->buff_enc.strcpy((this->tags & (TT_POINT_TAG_HEIGHT_PQ |
             TT_POINT_TAG_HEIGHT_NQ | TT_POINT_TAG_HEIGHT_UQ)) != 0 ? "?" : "" );
-        fprintf(out->file,"%s etex,",utf2tex(this->db->buff_enc.get_buffer()));
+        fprintf(out->file,"%s etex,",utf2tex(this->db->buff_enc.get_buffer()).c_str());
         postprocess_label = "p_label_mode_height";
       }
       postprocess = false;
@@ -641,7 +643,7 @@ bool thpoint::export_mp(class thexpmapmpxs * out)
         out->layout->export_mptex_font_size(out->file, this, false);
 
         fprintf(out->file,"%s etex,",
-            utf2tex(((thdate *)this->text)->get_str(TT_DATE_FMT_LOCALE)));
+            utf2tex(((thdate *)this->text)->get_str(TT_DATE_FMT_LOCALE)).c_str());
         postprocess_label = "p_label_mode_date";
       }
       postprocess = false;
@@ -703,14 +705,14 @@ bool thpoint::export_mp(class thexpmapmpxs * out)
           fprintf(out->file,"{");
           out->layout->export_mptex_font_size(out->file, this, false);
 
-          fprintf(out->file,"%s}", utf2tex(out->layout->units.format_human_length(this->xsize)));
+          fprintf(out->file,"%s}", utf2tex(out->layout->units.format_human_length(this->xsize)).c_str());
         }
 
         if (!thisnan(this->ysize)) {
           fprintf(out->file,"{");
           out->layout->export_mptex_font_size(out->file, this, false);
 
-          fprintf(out->file,"%s}", utf2tex(out->layout->units.format_human_length(this->ysize)));
+          fprintf(out->file,"%s}", utf2tex(out->layout->units.format_human_length(this->ysize)).c_str());
         }
 
         fprintf(out->file," etex,");
@@ -1079,7 +1081,7 @@ void thpoint::parse_value(char * ss, bool is_dist) {
     case TT_POINT_TYPE_EXTRA:
       opt_ok = is_dist;
       if (!opt_ok) {
-          thwarning(("%s [%d] -- using -value with point extra is deprecated, please use -dist instead", this->source.name, this->source.line));
+          thwarning(("%s [%lu] -- using -value with point extra is deprecated, please use -dist instead", this->source.name, this->source.line));
     	  opt_ok = true;
       }
       break;
