@@ -27,18 +27,16 @@
  
 #include "thscrap.h"
 #include "thexception.h"
-#include "thchenc.h"
 #include "thtflength.h"
 #include "thinfnan.h"
 #include "thdb1d.h"
 #include "thdb2d.h"
-#include "thdb2dmi.h"
 #include "th2ddataobject.h"
 #include "thline.h"
 #include "thpoint.h"
 #include "thscrapis.h"
 #include "thsurvey.h"
-#include "thsymbolset.h"
+#include "thsymbolsetlist.h"
 #include "thsketch.h"
 #include "thcsdata.h"
 #include "thdatabase.h"
