@@ -34,11 +34,9 @@
 #include "thdatabase.h"
 #include "thdataobject.h"
 #include "thsurvey.h"
-#include "th2ddataobject.h"
 #include "thscrap.h"
 #include <vector>
 #include "thchenc.h"
-#include <algorithm>
 #include "thmap.h"
 
 #include <fmt/printf.h>
