@@ -33,6 +33,8 @@
 #include "th2ddataobject.h"
 #include "thpoint.h"
 #include "thconfig.h"
+#include "thdatabase.h"
+#include <cstring>
 
 thwarp::~thwarp() {}
    
