@@ -270,17 +270,17 @@ case $tcl_platform(platform) {
     package require registry
     set xth(win32registry) {HKEY_LOCAL_MACHINE\SOFTWARE\Therion}
     if {[catch {
-      set xth(gui,compcmd) "\"[file join [registry get $xth(win32registry) InstallDir] therion.exe]\""
+      set xth(gui,compcmd) "\"[file join [registry -64bit get $xth(win32registry) InstallDir] therion.exe]\""
     }]} {
       set xth(win32registry) {HKEY_CURRENT_USER\SOFTWARE\Therion}
       catch {
-	set xth(gui,compcmd) "\"[file join [registry get $xth(win32registry) InstallDir] therion.exe]\""
+	set xth(gui,compcmd) "\"[file join [registry -64bit get $xth(win32registry) InstallDir] therion.exe]\""
       }      
     }
     
     catch {
-      if {[registry get {HKEY_LOCAL_MACHINE\SOFTWARE\Therion} AppCtrl]} {
-	set xth(gui,appctrlcmd) "[file join [registry get $xth(win32registry) InstallDir] bin appctrl.exe]"
+      if {[registry -64bit get {HKEY_LOCAL_MACHINE\SOFTWARE\Therion} AppCtrl]} {
+	set xth(gui,appctrlcmd) "[file join [registry -64bit get $xth(win32registry) InstallDir] bin appctrl.exe]"
       }
     }
     regsub -all {\/} $xth(gui,compcmd) {\\\\} xth(gui,compcmd)
