@@ -335,6 +335,7 @@ proc xth_te_show_file {fidx} {
     $xth(te,menu) entryconfigure [mc "Edit"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Save"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Save as"] -state normal
+    $xth(te,menu,file) entryconfigure [mc "Import"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Save all"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Auto save"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Close"] -state normal
@@ -362,6 +363,7 @@ proc xth_te_show_file {fidx} {
     set xth(te,open_file_encoding) $xth(app,fencoding)
     $xth(te,menu,file) entryconfigure [mc "Save"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Save as"] -state disabled
+    $xth(te,menu,file) entryconfigure [mc "Import"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Save all"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Auto save"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Close"] -state disabled
@@ -405,7 +407,7 @@ proc xth_te_set_encoding {} {
     } else {
       MessageDlg $xth(gui,message) -parent $xth(gui,main) \
         -icon error -type ok \
-        -message "uknown encoding -- $xth(te,open_file_encoding)" \
+        -message "unknown encoding -- $xth(te,open_file_encoding)" \
         -font $xth(gui,lfont)
     }
   }
@@ -486,28 +488,9 @@ proc xth_te_create_file {} {
   bind $cfr.txt <$xth(kb_control)-Key-i> "$iac {xth_te_auto_indent}"
   bind $cfr.txt <$xth(kb_control)-Key-s> "$iac {xth_te_save_file 0 $cfid}"
   bind $cfr.txt <Destroy> "xth_te_before_close_file $cfid yesno"  
-#  if {$xth(gui,bindclip) == 1} {
-    bind $cfr.txt <$xth(kb_control)-Key-x> "$iac {tk_textCut $cfr.txt}"
-    bind $cfr.txt <$xth(kb_control)-Key-c> "$iac {tk_textCopy $cfr.txt}"
-    bind $cfr.txt <$xth(kb_control)-Key-v> "$iac {tk_textPaste $cfr.txt}"
-    bind $cfr.txt <$xth(kb_control)-Key-z> "$iac {catch {$cfr.txt edit undo}}"
-    bind $cfr.txt <$xth(kb_control)-Key-y> "$iac {catch {$cfr.txt edit redo}}"
-  if {$xth(gui,bindinsdel)} {
-    bind $cfr.txt <Delete> {
-      %W delete insert
-      %W see insert
-    }
-    bind $cfr.txt <Shift-Key-Delete> "$iac {tk_textCut $cfr.txt}"
-    bind $cfr.txt <$xth(kb_control)-Key-Insert> "$iac {tk_textCopy $cfr.txt}"
-    bind $cfr.txt <Shift-Key-Insert> "$iac {tk_textPaste $cfr.txt}"
-#    catch {
-#      bind $cfr.txt <Shift-Key-KP_Decimal> "$iac {tk_textCut $cfr.txt}"
-#      bind $cfr.txt <$xth(kb_control)-Key-KP_Insert> "$iac {tk_textCopy $cfr.txt}"
-#      bind $cfr.txt <Shift-Key-KP_0> "$iac {tk_textPaste $cfr.txt}"
-#    }
-  }
-#  }
-    
+
+  xth_app_text_copy_paste_binds $cfr.txt $iac
+
   grid columnconf $cfr 0 -weight 1
   grid rowconf $cfr 0 -weight 1
   grid $cfr.txt -column 0 -row 0 -sticky news
@@ -520,6 +503,7 @@ proc xth_te_create_file {} {
   $xth(ctrl,te,files).fl.flbox insert end "[llength $xth(te,flist)]. $xth(te,$cfid,name) ($xth(te,$cfid,path))"
   
   xth_te_show_file [expr [llength $xth(te,flist)] - 1]
+
 }
 
 
@@ -546,6 +530,11 @@ proc xth_te_read_file {pth} {
   fconfigure $fid -encoding $curenc
   while {[eof $fid] != 1} {
     gets $fid fln
+    if {$flnn == 0} {
+        if {[scan [string index $fln 0] %c] == 65279} {
+            set fln [string range $fln 1 end]
+        }
+    }
     # replace tabs
     regsub -all {\t} $fln "  " fln
     incr flnn
@@ -599,11 +588,11 @@ proc xth_te_write_file {pth enc txt} {
     return [list $success $nm]
   }
   
-  fconfigure $fid -encoding $curenc -translation {auto lf}
+  fconfigure $fid -encoding $curenc -translation {auto auto}
   if {![string equal $xth(prj,name) svxedit]} {
     puts $fid "encoding  $enc"
   }
-  fconfigure $fid -encoding $enc -translation {auto lf}
+  fconfigure $fid -encoding $enc -translation {auto auto}
   puts -nonewline $fid $txt
   close $fid
   return [list $success $nm]
@@ -648,7 +637,7 @@ proc xth_te_open_file {dialogid fname fline} {
   if {$dialogid} {
     set fname [tk_getOpenFile -filetypes $xth(app,te,filetypes) \
       -parent $xth(gui,main) \
-      -initialdir $xth(gui,initdir) -defaultextension $xth(app,te,fileext)]
+      -initialdir $xth(gui,initdir) ]
   }
   
   if {[string length $fname] == 0} {
@@ -696,8 +685,12 @@ proc xth_te_open_file {dialogid fname fline} {
     $xth(te,$cfid,frame).txt edit reset
   }
   set xth(te,$cfid,otext) [$xth(te,$cfid,frame).txt get 1.0 end]
-  xth_te_show_file $xth(te,fcurr) 
-  $xth(te,$cfid,frame).txt mark set insert "$fline.0"
+  xth_te_show_file $xth(te,fcurr)
+  if {$fline > 0} { 
+      $xth(te,$cfid,frame).txt mark set insert "$fline.0"
+  } else {
+      $xth(te,$cfid,frame).txt mark set insert "1.0"
+  }
   $xth(te,$cfid,frame).txt see insert
   if {$fline > 0} {
     $xth(te,$cfid,frame).txt tag remove sel 1.0 end
@@ -708,6 +701,7 @@ proc xth_te_open_file {dialogid fname fline} {
   return 1
 }
 
+
 proc xth_te_before_close_file {cfid btns} {
   global xth
   if {
@@ -785,7 +779,7 @@ proc xth_te_save_file {dialogid cfid} {
   if {$dialogid} {
     set fname [tk_getSaveFile -filetypes $xth(app,te,filetypes) \
       -parent $xth(gui,main) \
-      -initialfile [file tail $fname] -initialdir [file dirname $fname] \
+      -initialfile [file tail $fname] -initialdir [xth_getdir $fname] \
       -defaultextension $xth(app,te,fileext)]
   }
   
@@ -868,12 +862,18 @@ proc xth_te_select_all {} {
   }
 }
 
+proc xth_te_new_file {} {
+  global xth
+  xth_te_create_file 
+  set cfid [lindex $xth(te,flist) $xth(te,fcurr)]
+  xth_te_insert_text $xth(te,$cfid,frame).txt $xth(te,template)
+}
 
-$xth(te,menu,file) add command -label [mc "New"] -command xth_te_create_file \
+$xth(te,menu,file) add command -label [mc "New"] -command xth_te_new_file \
   -font $xth(gui,lfont) -underline 0
 $xth(te,menu,file) add command -label [mc "Open"] -underline 0 \
   -accelerator "$xth(gui,controlk)-o" \
-  -font $xth(gui,lfont) -command {xth_te_open_file 1 {} 1}
+  -font $xth(gui,lfont) -command {xth_te_open_file 1 {} 0}
 $xth(te,menu,file) add command -label [mc "Save"] -underline 0 \
   -accelerator "$xth(gui,controlk)-s" -state disabled \
   -font $xth(gui,lfont) -command {
@@ -897,6 +897,11 @@ $xth(te,menu,file) add command -state disabled -label [mc "Close"] -underline 0
   -font $xth(gui,lfont) \
   -command "xth_te_close_file"
 
+$xth(te,menu,file) add separator
+$xth(te,menu,file) add command -state disabled -label [mc "Import"] -underline 0 \
+  -font $xth(gui,lfont) \
+  -command "xth_te_import_file"
+
 $xth(te,menu,file) add separator
 $xth(te,menu,file) add command -state disabled -label [mc "Next"] \
   -accelerator "$xth(gui,controlk)-n" \
@@ -1100,5 +1105,11 @@ proc xth_te_text_auto_indent {W} {
   
 }
 
+
+
+
+
+
+
 xth_ctrl_minimize te sr
 xth_status_bar_status te [mc "Text editor is not active. To activate it, open existing file or create new one."]
